@@ -21,4 +21,4 @@ from .model.base_model import (
     ORM as ORM,
 )  # COMMENT: to avoid relative import we need to import BaseModel after import Table,Column, ForeignKey, IRepositoryBase and Disassembler
 
-from .engine import create_engine, URL  # noqa: F401
+from .engine import create_engine, URL, make_url # noqa: F401
