@@ -1,2 +1,2 @@
 from .create import create_engine  # noqa: F401
-from .url import URL  # noqa: F401
\ No newline at end of file
+from .url import URL, make_url  # noqa: F401
